provider "aws" {
  region = "ap-northeast-2"
}

locals {
  user_data = <<EOF
#!/bin/bash
echo "Hello Terraform!"
EOF
}

##################################################################
# Data sources to get VPC, subnet, security group and AMI details
##################################################################
data "aws_vpc" "production" {
  id = var.vpc_id
}

data "aws_subnet_ids" "private_1" {
  vpc_id = data.aws_vpc.production.id

  filter {
    name = "tag:Name"
    values = [ "subnet" ]
  }
}

data "aws_ami" "production" {
  owners = [ "111111111111" ]

  filter {
    name = "name"
    values = [ "AMI" ]
  }
}

data "aws_security_group" "production" {
  id = var.security_group_id
}

# resource "aws_eip" "this" {
#   vpc      = true
#   instance = module.ec2_cluster.id[0]
# }

# resource "aws_placement_group" "production" {
#   name     = "hunky-dory-pg"
#   strategy = "cluster"
# }

resource "aws_kms_key" "by_id" {
}

resource "aws_network_interface" "this" {
  count = 1

  subnet_id = tolist(data.aws_subnet_ids.private_1.ids)[count.index]
  security_groups = [data.aws_security_group.production.id]
}

module "ec2_cluster" {
  source                        = "terraform-aws-modules/ec2-instance/aws"
  version                       = "~> 2.0"

  name                          = "AMI"
  instance_count                = 1

  ami                           = data.aws_ami.production.id
  instance_type                 = "t3.medium"
  cpu_credits                   = "unlimited"
  ebs_optimized                 = true
  key_name                      = "production"
  monitoring                    = true
  # vpc_security_group_ids        = [module.security_group.this_security_group_id]
  # subnet_id                     = tolist(data.aws_subnet_ids.private_1.ids)[0]
  # associate_public_ip_address   = false
  # placement_group               = aws_placement_group.web.id
  iam_instance_profile          = "ec2_profile"

  user_data_base64 = base64encode(local.user_data)

  network_interface = [
    {
      device_index          = 0
      network_interface_id  = aws_network_interface.this[0].id
      delete_on_termination = false
    }
  ]

  metadata_options = {
    http_endpoint               = "enabled"
    http_tokens                 = "required"
    http_put_response_hop_limit = 8
  }

  tags = {
    Terraform       = "true"
    Environment     = "production"
    Name            = "AMI"
  }
}
